package
Version:
v0.0.0-...-8f79da8
Opens a new window with list of versions in this module.
Published: Aug 7, 2013
License: GPL-3.0
Opens a new window with license information.
Imports: 10
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
The parser is responsible for reading the body
of the HTTP request and returning buckets of data.
func NewLogData() *logData
Source Files
¶
Click to show internal directories.
Click to hide internal directories.